@@ -35,40 +35,44 @@ class LatexTest(unittest.TestCase):
         with open(get_data_dir() / 'large_matrix.tex','r') as f:
             tex = to_ltx(A,
                mark_elements=[(1,1),(2,3),(7,0)],
-               separate_columns=[0,1],
-               separate_rows=[0,1],
+               separate_columns=[1,2],
+               separate_rows=[1,2],
               )
             testtex = f.read()
+        assert(tex == testtex)
 
     def test_row_vector(self):
         with open(get_data_dir() / 'row_vector.tex','r') as f:
             tex = to_ltx(D,
                    mark_elements=[1,],
-                   separate_columns=[0,1],
-                   separate_rows=[0,1],
+                   separate_columns=[1,2],
+                   separate_rows=[1,2],
                   )
             testtex = f.read()
+        assert(tex == testtex)
 
     def test_column_vector(self):
         with open(get_data_dir() / 'column_vector.tex','r') as f:
             tex = to_ltx(D,
                is_row_vector=False,
                mark_elements=[1,],
-               separate_columns=[0,1],
-               separate_rows=[0,1],
+               separate_columns=[1,2],
+               separate_rows=[1,2],
                mark_color='yellow',
                brackets='(]',
               )
             testtex = f.read()
+        assert(tex == testtex)
 
     def test_Vmatrix(self):
         with open(get_data_dir() / 'Vmatrix.tex','r') as f:
             tex = to_ltx(D,
                latexarraytype='Vmatrix',
                is_row_vector=False,
-               separate_rows=[0,1],
+               separate_rows=[1,2],
               )
             testtex = f.read()
+        assert(tex == testtex)
 
     def test_imaginary(self):
         with open(get_data_dir() / 'imaginary.tex','r') as f:
@@ -76,6 +80,7 @@ class LatexTest(unittest.TestCase):
                    mark_elements=[(0,1)],
               )
             testtex = f.read()
+        assert(tex == testtex)
 
     def test_imaginary_exp(self):
         with open(get_data_dir() / 'imaginary_exp.tex','r') as f:
@@ -84,10 +89,31 @@ class LatexTest(unittest.TestCase):
                    fmt='{:4.2e}',
                   )
             testtex = f.read()
+        assert(tex == testtex)
 
     def test_mark_elements(self):
         self.assertRaises(ValueError,lambda: to_ltx(F,mark_elements=[1,1]))
         self.assertRaises(ValueError,lambda: to_ltx(F[0],mark_elements=[(1,1)]))
+        with open(get_data_dir() / 'Vmatrix.tex','r') as f:
+            tex = to_ltx(D,
+               latexarraytype='Vmatrix',
+               is_row_vector=False,
+               separate_rows=[1,2],
+               mark_elements=None,
+              )
+            testtex = f.read()
+        assert(tex == testtex)
+
+    def test_col_separator_error(self):
+        self.assertRaises(ValueError,
+            lambda: to_ltx(
+               D,
+               latexarraytype='Vmatrix',
+               is_row_vector=False,
+               separate_columns=[1,2],
+               )
+            )
+
 
     def test_shape(self):
         self.assertRaises(NotImplementedError, lambda:to_ltx([[[]]]))
@@ -99,9 +125,10 @@ class LatexTest(unittest.TestCase):
                    fmt='{:4.2e}',
                   )
             testtex = f.read()
+        assert(tex == testtex)
 
 
-if __name__ == "__main__":
+if __name__ == "__main__": # pragma: no cover
 
     T = LatexTest()
     T.test_large_matrix()
@@ -113,3 +140,4 @@ if __name__ == "__main__":
     T.test_mark_elements()
     T.test_shape()
     T.test_conversion()
+    T.test_col_separator_error()
